@@ -43,7 +43,7 @@ def mastertable_to_fasta(file='MasterTable.tsv', outfile='MasterTable.fna', mins
 def genbank_to_json(file):
     locus = 1
     i = {}
-    out = open('clean_'+file,'w')
+    out = open(file+'.clean.gbk','w')
     with open(file) as h:
         lines = h.readlines()
         for line in lines:
@@ -53,7 +53,7 @@ def genbank_to_json(file):
             else:
                 out.write(line)
     from Bio import GenBank
-    with open('clean_'+file) as h:
+    with open(file+'.clean.gbk') as h:
         for r in GenBank.parse(h):
             print(locus)
             lst = []
